@@ -42,7 +42,7 @@ public:
     // Unsigned integer division is usually
     // faster than signed integer division,
     // especially for int128_t.
-    using UT = typename port::make_unsigned<T>::type;
+    using UT = typename pstd::make_unsigned<T>::type;
 
     if (a < max_a())
       return phi((UT) x, a);
@@ -182,7 +182,7 @@ phi_tiny(T x, uint64_t a)
 {
   // If possible use smaller integer type
   // to speed up integer division.
-  if (x <= port::numeric_limits<uint64_t>::max())
+  if (x <= pstd::numeric_limits<uint64_t>::max())
     return phiTiny.phi_recursive((uint64_t) x, a);
   else
     return phiTiny.phi_recursive(x, a);
