@@ -51,9 +51,8 @@ int64_t P3(int64_t x, int64_t y, int64_t a, int threads, bool print = is_print()
 
 int64_t Li(int64_t);
 int64_t Li_inverse(int64_t);
-int64_t Ri(int64_t);
-int64_t Ri_inverse(int64_t);
-int64_t nth_prime_approx(int64_t n);
+int64_t RiemannR(int64_t);
+int64_t RiemannR_inverse(int64_t);
 
 #ifdef HAVE_INT128_T
   int128_t pi(int128_t x);
@@ -64,8 +63,8 @@ int64_t nth_prime_approx(int64_t n);
 
   int128_t Li(int128_t);
   int128_t Li_inverse(int128_t);
-  int128_t Ri(int128_t);
-  int128_t Ri_inverse(int128_t);
+  int128_t RiemannR(int128_t);
+  int128_t RiemannR_inverse(int128_t);
 #endif
 
 void set_status_precision(int precision);
