@@ -2,14 +2,14 @@
 /// @file  FactorTable.cpp
 /// @see   FactorTable.hpp for documentation
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
 ///
 
 #include <BaseFactorTable.hpp>
-#include <pod_vector.hpp>
+#include <Vector.hpp>
 
 #include <stdint.h>
 
@@ -20,7 +20,7 @@ namespace primecount {
 /// size of the table was obtained using the formula:
 /// \prod_{i=1}^{5} primes[i] - 1.
 ///
-const pod_array<uint16_t, 480> BaseFactorTable::coprime_ =
+const Array<uint16_t, 480> BaseFactorTable::coprime_ =
 {
   1, 13, 17, 19, 23, 29, 31, 37, 41, 43,
   47, 53, 59, 61, 67, 71, 73, 79, 83, 89,
@@ -77,7 +77,7 @@ const pod_array<uint16_t, 480> BaseFactorTable::coprime_ =
 /// and 11. The size of the table was obtained using the
 /// formula: \prod_{i=1}^{5} primes[i].
 ///
-const pod_array<int16_t, 2310> BaseFactorTable::coprime_indexes_ =
+const Array<int16_t, 2310> BaseFactorTable::coprime_indexes_ =
 {
  -1, 0, 0, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 1, 1, 1, 1, 2, 2, 3,
