@@ -10,7 +10,7 @@
 ///
 
 #include <primecount-internal.hpp>
-#include <generate.hpp>
+#include <generate_primes.hpp>
 #include <imath.hpp>
 #include <macros.hpp>
 #include <PiTable.hpp>
