@@ -28,22 +28,22 @@
 ///        In-depth description of this algorithm:
 ///        https://github.com/kimwalisch/primecount/blob/master/doc/Hard-Special-Leaves.md
 ///
-/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
 ///
 
 #include <Sieve.hpp>
+#include "Sieve_count.hpp"
 #include <imath.hpp>
 #include <int128_t.hpp>
 #include <macros.hpp>
 #include <min.hpp>
-#include <Vector.hpp>
-#include <popcnt.hpp>
 
 #include <stdint.h>
 #include <algorithm>
+#include <cmath>
 
 namespace {
 
@@ -274,7 +274,7 @@ Sieve::Sieve(uint64_t low,
   ASSERT(segment_size % 240 == 0);
 
   start_ = low;
-  segment_size = get_segment_size(segment_size);
+  segment_size = align_segment_size(segment_size);
 
   // sieve_size = segment_size / 30 as each byte corresponds
   // to 30 numbers i.e. the 8 bits correspond to the
@@ -302,22 +302,23 @@ void Sieve::allocate_counter(uint64_t low)
   double counter_dist = std::sqrt(average_leaf_dist);
 
   // Here we balance counting with the counter array and
-  // counting from the sieve array using the POPCNT
-  // instruction. Since the POPCNT instructions allows to
-  // count a distance of 240 using a single instruction we
-  // slightly increase the counter distance and slightly
-  // decrease the size of the counter array.
-  counter_.dist = uint64_t(counter_dist * std::sqrt(240));
-
-  // Each byte represents an interval of size 30
-  uint64_t bytes = counter_.dist / 30;
+  // counting from the sieve array using the 64-bit POPCNT
+  // instruction. Since the 64-bit POPCNT instructions
+  // allows to count a distance of 240 using a single
+  // instruction we slightly increase the counter distance
+  // and slightly decrease the size of the counter array.
+  uint64_t bytes_count_instruction = bytes_per_count_instruction();
+  ASSERT(bytes_count_instruction >= sizeof(uint64_t));
+  uint64_t dist_per_instruction = bytes_count_instruction * 30;
+  counter_.dist = uint64_t(counter_dist * std::sqrt(dist_per_instruction));
 
   // Increasing the minimum counter distance decreases the
-  // branch mispredictions but on the other hand increases
-  // the number of executed instructions. On newer CPUs
-  // reducing the branch mispredictions is more important
-  // than reducing the number of executed instructions.
-  bytes = max((uint64_t) sizeof(uint64_t) * 16, bytes);
+  // branch mispredictions (good) but on the other hand
+  // increases the number of executed instructions (bad).
+  // In my benchmarks setting the minimum amount of bytes to
+  // bytes_count_instruction * 8 (or 16) performed best.
+  uint64_t bytes = counter_.dist / 30;
+  bytes = max(bytes, bytes_count_instruction * 8);
   bytes = next_power_of_2(bytes);
 
   // Make sure the counter (32-bit) doesn't overflow.
@@ -344,7 +345,7 @@ uint64_t Sieve::segment_size() const
 /// process 64-bit words (8 bytes) and each
 /// byte contains 30 numbers.
 ///
-uint64_t Sieve::get_segment_size(uint64_t size)
+uint64_t Sieve::align_segment_size(uint64_t size)
 {
   size = max(size, 240);
 
@@ -362,7 +363,7 @@ void Sieve::reset_sieve(uint64_t low, uint64_t high)
   if (size < segment_size())
   {
     uint64_t last = size - 1;
-    size = get_segment_size(size);
+    size = align_segment_size(size);
     sieve_.resize(size / 30);
     auto sieve64 = (uint64_t*) sieve_.data();
     sieve64[last / 240] &= unset_larger[last % 240];
@@ -416,6 +417,11 @@ void Sieve::add(uint64_t prime)
   // is not divisible by 2, 3, 5
   uint64_t factor = wheel_init[quotient % 30].factor;
   multiple += prime * factor;
+
+  ASSERT(multiple % 2 != 0);
+  ASSERT(multiple % 3 != 0);
+  ASSERT(multiple % 5 != 0);
+
   multiple = (multiple - start_) / 30;
   uint32_t multiple32 = (uint32_t) multiple;
 
@@ -447,6 +453,8 @@ void Sieve::cross_off(uint64_t prime, uint64_t i)
       return; \
     }
 
+  ASSERT(wheel.index <= 63);
+
   switch (wheel.index)
   {
     for (;;)
@@ -718,6 +726,8 @@ void Sieve::cross_off_count(uint64_t prime, uint64_t i)
       total_count -= (uint64_t) is_bit; \
     }
 
+  ASSERT(wheel.index <= 63);
+
   switch (wheel.index)
   {
     for (;;)
