@@ -18,7 +18,7 @@
 #include <PiTable.hpp>
 #include <primecount-internal.hpp>
 #include <fast_div.hpp>
-#include <generate.hpp>
+#include <generate_primes.hpp>
 #include <int128_t.hpp>
 #include <min.hpp>
 #include <imath.hpp>
@@ -166,7 +166,7 @@ int128_t S2_easy(int128_t x,
   int128_t sum;
 
   // uses less memory
-  if (y <= port::numeric_limits<uint32_t>::max())
+  if (y <= pstd::numeric_limits<uint32_t>::max())
   {
     auto primes = generate_primes<uint32_t>(y);
     sum = S2_easy_OpenMP((uint128_t) x, y, z, c, primes, threads, is_print);
