@@ -36,7 +36,7 @@
 #include <primecount-internal.hpp>
 #include <LoadBalancerAC.hpp>
 #include <fast_div.hpp>
-#include <generate.hpp>
+#include <generate_primes.hpp>
 #include <gourdon.hpp>
 #include <int128_t.hpp>
 #include <libdivide.h>
@@ -326,7 +326,7 @@ T AC_OpenMP(T x,
   // dual-socket AMD EPYC 7642 server with 192 CPU cores.
   int64_t thread_threshold = 1000;
   int max_threads = (int) std::pow(xz, 1 / 3.7);
-  threads = std::min(threads, max_threads);
+  threads = min(threads, max_threads);
   threads = ideal_num_threads(x13, threads, thread_threshold);
   LoadBalancerAC loadBalancer(sqrtx, y, threads, is_print);
 
@@ -386,13 +386,13 @@ T AC_OpenMP(T x,
       int64_t low = thread.low;
       int64_t segment_size = thread.segment_size;
       int64_t limit = low + thread.segments * segment_size;
-      limit = std::min(limit, sqrtx);
+      limit = min(limit, sqrtx);
 
       for (; low < limit; low += segment_size)
       {
         // Current segment [low, high[
         int64_t high = low + segment_size;
-        high = std::min(high, sqrtx);
+        high = min(high, sqrtx);
         segmentedPi.init(low, high);
 
         // We measure the thread computation time excluding the
@@ -428,7 +428,7 @@ T AC_OpenMP(T x,
           int64_t prime = primes[b];
           T xp = x / prime;
 
-          if (xp <= port::numeric_limits<uint64_t>::max())
+          if (xp <= pstd::numeric_limits<uint64_t>::max())
             sum += C2_64(xlow, xhigh, (uint64_t) xp, y, b, prime, lprimes, pi, segmentedPi);
           else
             sum += C2_128(xlow, xhigh, xp, y, b, primes, pi, segmentedPi);
@@ -440,7 +440,7 @@ T AC_OpenMP(T x,
           int64_t prime = primes[b];
           T xp = x / prime;
 
-          if (xp <= port::numeric_limits<uint64_t>::max())
+          if (xp <= pstd::numeric_limits<uint64_t>::max())
             sum += A_64(xlow, xhigh, (uint64_t) xp, y, prime, lprimes, pi, segmentedPi);
           else
             sum += A_128(xlow, xhigh, xp, y, prime, primes, pi, segmentedPi);
@@ -513,7 +513,7 @@ int128_t AC(int128_t x,
   int128_t sum;
 
   // uses less memory
-  if (max_prime <= port::numeric_limits<uint32_t>::max())
+  if (max_prime <= pstd::numeric_limits<uint32_t>::max())
   {
     auto primes = generate_primes<uint32_t>(max_prime);
     sum = AC_OpenMP((uint128_t) x, y, z, k, x_star, max_a_prime, primes, threads, is_print);
