@@ -7,7 +7,7 @@
 ///        Load balancing is described in more detail at:
 ///        https://github.com/kimwalisch/primecount/blob/master/doc/Easy-Special-Leaves.md
 ///
-/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -42,18 +42,18 @@ LoadBalancerAC::LoadBalancerAC(int64_t sqrtx,
   // This size performs well near 1e16 on my AMD EPYC 2.
   int64_t min_segment_size = (1 << 9) * SegmentedPiTable::numbers_per_byte();
 
-  // The maximum segment size matches the CPU's L2 cache
-  // size (unless x^(1/4) > L2 cache size). This way
+  // The maximum segment size matches the CPU's L1 cache
+  // size (unless x^(1/4) > L1 cache size). This way
   // we ensure that most memory accesses will be cache
   // hits and we get good performance.
-  int64_t l2_segment_size = L2_CACHE_SIZE * SegmentedPiTable::numbers_per_byte();
+  int64_t L1_segment_size = L1_CACHE_SIZE * SegmentedPiTable::numbers_per_byte();
 
   if (threads == 1 && !is_print)
   {
     // When using a single thread (and printing is disabled)
     // we can use a segment size larger than x^(1/4)
     // because load balancing is only needed for multi-threading.
-    segment_size_ = std::max(x14, l2_segment_size);
+    segment_size_ = std::max(x14, L1_segment_size);
     segments_ = ceil_div(sqrtx, segment_size_);
   }
   else
@@ -67,9 +67,9 @@ LoadBalancerAC::LoadBalancerAC(int64_t sqrtx,
   }
 
   segment_size_ = std::max(min_segment_size, segment_size_);
-  segment_size_ = SegmentedPiTable::get_segment_size(segment_size_);
-  max_segment_size_ = std::max(l2_segment_size, segment_size_);
-  max_segment_size_ = SegmentedPiTable::get_segment_size(max_segment_size_);
+  segment_size_ = SegmentedPiTable::align_segment_size(segment_size_);
+  max_segment_size_ = std::max(L1_segment_size, segment_size_);
+  max_segment_size_ = SegmentedPiTable::align_segment_size(max_segment_size_);
 
   if (is_print_)
     print_status(get_time());
@@ -106,7 +106,7 @@ bool LoadBalancerAC::get_work(ThreadDataAC& thread)
       thread.secs < increase_threshold &&
       thread.segments == segments_ &&
       thread.segment_size == segment_size_ &&
-      segments_ * segment_size_ * (threads_ * 8) < remaining_dist)
+      segment_size_ * segments_ * (threads_ * 8) < remaining_dist)
   {
     int64_t increase_factor = 2;
 
@@ -116,7 +116,7 @@ bool LoadBalancerAC::get_work(ThreadDataAC& thread)
     {
       segment_size_ = segment_size_ * increase_factor;
       segment_size_ = std::min(segment_size_, max_segment_size_);
-      segment_size_ = SegmentedPiTable::get_segment_size(segment_size_);
+      segment_size_ = SegmentedPiTable::align_segment_size(segment_size_);
     }
   }
 
@@ -126,7 +126,7 @@ bool LoadBalancerAC::get_work(ThreadDataAC& thread)
   thread.low = low_;
   thread.segments = segments_;
   thread.segment_size = segment_size_;
-  low_ = std::min(low_ + segments_ * segment_size_, sqrtx_);
+  low_ = std::min(low_ + segment_size_ * segments_, sqrtx_);
   segment_nr_++;
 
   return thread.low < sqrtx_;
@@ -141,15 +141,23 @@ void LoadBalancerAC::print_status(double time)
     print_time_ = time;
 
     int64_t remaining_dist = sqrtx_ - low_;
-    int64_t thread_dist = segments_ * segment_size_;
+    int64_t thread_dist = segment_size_ * segments_;
     int64_t total_segments = ceil_div(remaining_dist, thread_dist);
     total_segments += segment_nr_;
 
     std::ostringstream status;
-    // Clear line because total_segments may become smaller
-    status << "\r                                    "
-           << "\rSegments: " << segment_nr_ << '/' << total_segments;
-    std::cout << status.str() << std::flush;
+    status << "\rSegments: " << segment_nr_ << '/' << total_segments;
+
+    if (status.str().size() >= prev_status_size_)
+      std::cout << status.str() << std::flush;
+    else
+    {
+      std::ostringstream clear_status;
+      clear_status << "\r" << std::string(prev_status_size_, ' ') << status.str();
+      std::cout << clear_status.str() << std::flush;
+    }
+
+    prev_status_size_ = status.str().size();
   }
 }
 
