@@ -18,7 +18,7 @@
 ///        method, Revista do DETUA, vol. 4, no. 6, March 2006,
 ///        pp. 759-768.
 ///
-/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -26,8 +26,8 @@
 
 #include <primecount-internal.hpp>
 #include <Sieve.hpp>
-#include <generate.hpp>
-#include <generate_phi.hpp>
+#include <generate_primes.hpp>
+#include <phi_vector.hpp>
 #include <LoadBalancerS2.hpp>
 #include <min.hpp>
 #include <imath.hpp>
@@ -44,14 +44,14 @@ using namespace primecount;
 namespace {
 
 /// Compute the S2 contribution of the interval
-/// [low, low + segments * segment_size[.
+/// [low, low + segment_size * segments[.
 ///
 int64_t S2_thread(int64_t x,
                   int64_t y,
                   int64_t z,
                   int64_t c,
                   const PiTable& pi,
-                  const Vector<int32_t>& primes,
+                  const Vector<uint32_t>& primes,
                   const Vector<int32_t>& lpf,
                   const Vector<int32_t>& mu,
                   ThreadData& thread)
@@ -62,7 +62,7 @@ int64_t S2_thread(int64_t x,
   int64_t segments = thread.segments;
   int64_t segment_size = thread.segment_size;
   int64_t pi_sqrty = pi[isqrt(y)];
-  int64_t limit = min(low + segments * segment_size, z + 1);
+  int64_t limit = min(low + segment_size * segments, z + 1);
   int64_t max_b = pi[min(isqrt(x / low1), y - 1)];
   int64_t min_b = pi[min(z / limit, primes[max_b])];
   min_b = max(c, min_b) + 1;
@@ -70,7 +70,7 @@ int64_t S2_thread(int64_t x,
   if (min_b > max_b)
     return 0;
 
-  auto phi = generate_phi(low, max_b, primes, pi);
+  Vector<int64_t> phi = phi_vector(low, max_b, primes, pi);
   Sieve sieve(low, segment_size, max_b);
   thread.init_finished();
 
@@ -104,8 +104,8 @@ int64_t S2_thread(int64_t x,
         if (mu[m] != 0 && prime < lpf[m])
         {
           int64_t xpm = x / (prime * m);
-          int64_t stop = xpm - low;
-          int64_t phi_xpm = phi[b] + sieve.count(stop);
+          int64_t count = sieve.count(xpm - low);
+          int64_t phi_xpm = phi[b] + count;
           sum -= mu[m] * phi_xpm;
         }
       }
@@ -130,8 +130,8 @@ int64_t S2_thread(int64_t x,
       for (; primes[l] > min_m; l--)
       {
         int64_t xpq = x / (prime * primes[l]);
-        int64_t stop = xpq - low;
-        int64_t phi_xpq = phi[b] + sieve.count(stop);
+        int64_t count = sieve.count(xpq - low);
+        int64_t phi_xpq = phi[b] + count;
         sum += phi_xpq;
       }
 
@@ -168,7 +168,7 @@ int64_t S2(int64_t x,
            int64_t z,
            int64_t c,
            int64_t s2_approx,
-           const Vector<int32_t>& primes,
+           const Vector<uint32_t>& primes,
            const Vector<int32_t>& lpf,
            const Vector<int32_t>& mu,
            int threads,
@@ -180,6 +180,7 @@ int64_t S2(int64_t x,
   {
     print("");
     print("=== S2(x, y) ===");
+    print("Algorithm: " SIEVE_COUNT_ALGO_NAME);
     time = get_time();
   }
 
@@ -242,7 +243,7 @@ int64_t pi_lmo_parallel(int64_t x,
     print(x, y, z, c, threads);
   }
 
-  auto primes = generate_primes<int32_t>(y);
+  auto primes = generate_primes<uint32_t>(y);
   auto lpf = generate_lpf(y);
   auto mu = generate_moebius(y);
 
