@@ -103,19 +103,19 @@ int main()
   static_assert(ct_sqrt(9223372037000250000ull) == 3037000500ull, "ct_sqrt(3037000500^2) failed!");
   static_assert(ct_sqrt(9223372037000250001ull) == 3037000500ull, "ct_sqrt(3037000500^2+1) failed!");
 
-  static_assert(ct_sqrt(port::numeric_limits<int8_t>::max()) == 11, "ct_sqrt(2^7-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<uint8_t>::max()) == 15, "ct_sqrt(2^8-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<int16_t>::max()) == 181, "ct_sqrt(2^15-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<uint16_t>::max()) == 255, "ct_sqrt(2^16-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<int32_t>::max()) == 46340, "ct_sqrt(2^31-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<uint32_t>::max()) == 65535, "ct_sqrt(2^32-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<int64_t>::max()) == 3037000499ll, "ct_sqrt(2^63-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<uint64_t>::max()) == 4294967295ull, "ct_sqrt(2^64-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<int8_t>::max()) == 11, "ct_sqrt(2^7-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<uint8_t>::max()) == 15, "ct_sqrt(2^8-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<int16_t>::max()) == 181, "ct_sqrt(2^15-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<uint16_t>::max()) == 255, "ct_sqrt(2^16-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<int32_t>::max()) == 46340, "ct_sqrt(2^31-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<uint32_t>::max()) == 65535, "ct_sqrt(2^32-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<int64_t>::max()) == 3037000499ll, "ct_sqrt(2^63-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<uint64_t>::max()) == 4294967295ull, "ct_sqrt(2^64-1) failed!");
 
 #if defined(HAVE_INT128_T)
 
-  static_assert(ct_sqrt(port::numeric_limits<int128_t>::max()) == 13043817825332782212ull, "ct_sqrt(2^127-1) failed!");
-  static_assert(ct_sqrt(port::numeric_limits<uint128_t>::max()) == 18446744073709551615ull, "ct_sqrt(2^128-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<int128_t>::max()) == 13043817825332782212ull, "ct_sqrt(2^127-1) failed!");
+  static_assert(ct_sqrt(pstd::numeric_limits<uint128_t>::max()) == 18446744073709551615ull, "ct_sqrt(2^128-1) failed!");
 
   // here std::sqrt((double) 443075998594972078030832658571409090) is 1 too small
   static_assert(ct_sqrt((((int128_t) 24019198012642651) << 64) | 15864680554123835074ull) == 665639541039271553ll, "ct_sqrt(443075998594972078030832658571409090) failed!");
